pkgsrc-Bugs archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

Re: pkg/33792: multimedia/mpeg4ip gcc3.4.3 Solaris10




> >Synopsis:       multimedia/mpeg4ip gcc3.4.3 Solaris10
> 
> 
> >Fix:
> 

Fix for Solaris see Attachments
# $NetBSD: Makefile,v 1.8 2006/06/12 16:28:12 wiz Exp $

DISTNAME=               mpeg4ip-1.5
PKGREVISION=            2
CATEGORIES=             multimedia
MASTER_SITES=           ${MASTER_SITE_SOURCEFORGE:=mpeg4ip/}

MAINTAINER=             pkgsrc-users%NetBSD.org@localhost
HOMEPAGE=               http://mpeg4ip.sourceforge.net/
COMMENT=                Tools for streaming video and audio

CONFLICTS+=             faad2<2.0nb6

USE_LANGUAGES=          c c++
USE_PKGLOCALEDIR=       yes
USE_LIBTOOL=            yes
GNU_CONFIGURE=          yes
CONFIGURE_SCRIPT=       bootstrap
LIBTOOL_OVERRIDE=       libtool */libtool */*/libtool */*/*/libtool

CFLAGS.SunOS+=          -DHAVE_INET_NTOP

.include "../../devel/SDL/buildlink3.mk"
.include "../../mk/x11.buildlink3.mk"
.include "../../mk/bsd.pkg.mk"
--- lib/utils/config_opts.cpp.orig      Tue May  4 20:53:09 2004
+++ lib/utils/config_opts.cpp   Thu Jun 22 11:48:28 2006
@@ -22,7 +22,7 @@
   memset(long_options, 0, opts_size);
   
   for (ix = 0; ix < max_vars; ix++) {
-    long_options[ix].name = pConfig->GetNameFromIndex(ix);
+    long_options[ix].name = (char*) pConfig->GetNameFromIndex(ix);
     long_options[ix].has_arg = pConfig->GetTypeFromIndex(ix) == 
CONFIG_TYPE_BOOL ? 2 : 1;
     long_options[ix].val = base_offset + ix;
   }
--- common/video/iso-mpeg4/src/vtc_ztq_QMInit.cpp.orig  Wed May  4 21:56:01 2005
+++ common/video/iso-mpeg4/src/vtc_ztq_QMInit.cpp       Thu Jun 22 12:54:40 2006
@@ -78,7 +78,8 @@
     {
       noteError("Can't allocate memory for prevQList.");
       err = -1;
-      goto ERR;
+/* ERR is still define in Solaris */
+      goto TheERR;
     }
 
   /* allocatate memory for prevQList2 */
@@ -88,7 +89,7 @@
     {
       noteError("Can't allocate memory for prevQList.");
       err = -1;
-      goto ERR;
+      goto TheERR;
     }
 
   /* allocatate memory for prevQList */
@@ -98,10 +99,10 @@
     {
       noteError("Can't allocate memory for scaleLev.");
       err = -1;
-      goto ERR;
+      goto TheERR;
     }
 
-ERR:
+TheERR:
   return err;
 }
 


Home | Main Index | Thread Index | Old Index
--- lib/rtp/rtp.c.orig  Tue Mar 21 00:08:24 2006
+++ lib/rtp/rtp.c       Thu Jun 22 12:19:44 2006
@@ -74,6 +74,8 @@
  */
 #define MAX_ENCRYPTION_PAD 16
 
+#define MAX(a,b) ((a) > (b) ? (a) : (b))
+
 static int rijndael_initialize(struct rtp *session, u_char *hash, int 
hash_len);
 
 static int rijndael_decrypt(void *ifptr, uint8_t *data,
--- common/video/iso-mpeg4/include/PEZW_zerotree.hpp.orig       Thu Jun 22 
12:39:14 2006
+++ common/video/iso-mpeg4/include/PEZW_zerotree.hpp    Thu Jun 22 12:46:41 2006
@@ -78,7 +78,12 @@
 
 /* for internal use only, not sent as zerotree symbols  */
 #define DZ     4               /* descendant of a ZTRV */
-/*#define DS     4               /* descendant of a ZTRS */
+/*#define DS     4            */   /* descendant of a ZTRS */
+/* in Solaris i386 DS is define as :
+   The names and offsets defined here are specified by i386 ABI suppl.
+   in /usr/include/sys/regset.h
+   and conflict with this def.
+*/
 #undef DS
 #define SKIP   13                      /* out of shape */                      
                        
 #define SKPZTR 14                      /* out of shape and zero tree root */   